@@ -279,13 +279,15 @@ class ChunkedArray(awkward.array.base.AwkwardArray):
         if self.countsknown:
             return super(ChunkedArray, self).__str__()
         else:
-            strs = [awkward.util.array_str(x) for x in self[:7]]
+            strs = [awkward.util.array_str(x) for x in self[:7].__iter__(checkiter=False)]
             if len(strs) < 7:
                 return super(ChunkedArray, self).__str__()
             else:
                 return "[{0} ...]".format(" ".join(strs))
 
-    def __iter__(self):
+    def __iter__(self, checkiter=True):
+        if checkiter:
+            self._checkiter()
         for i, chunk in enumerate(self._chunks):
             if i >= len(self._counts):
                 self._counts.append(len(chunk))
@@ -293,6 +295,8 @@ class ChunkedArray(awkward.array.base.AwkwardArray):
                 yield x
 
     def __array__(self, *args, **kwargs):
+        self._checktonumpy()
+
         if isinstance(self.type.to, awkward.util.numpy.dtype):
             if len(self) == 0:
                 return awkward.util.numpy.empty(0, dtype=awkward.util.DEFAULTTYPE)
